@@ -1662,6 +1662,46 @@ class AutogenRenderTest(TestBase):
             "    # ### end Alembic commands ###",
         )
 
+    def test_render_server_default_no_context(self):
+        uo = ops.UpgradeOps(
+            ops=[
+                ops.CreateTableOp(
+                    "sometable",
+                    [Column("x", types.DateTime(), server_default=func.now())],
+                )
+            ]
+        )
+
+        eq_ignore_whitespace(
+            autogenerate.render_python_code(uo),
+            "# ### commands auto generated by Alembic - please adjust! ###\n"
+            "    op.create_table('sometable',\n"
+            "    sa.Column('x', sa.DateTime(), "
+            "server_default=sa.text(!U'now()'), nullable=True)\n"
+            "    )\n"
+            "    # ### end Alembic commands ###",
+        )
+
+    def test_render_server_default_context_passed(self):
+        uo = ops.UpgradeOps(
+            ops=[
+                ops.CreateTableOp(
+                    "sometable",
+                    [Column("x", types.DateTime(), server_default=func.now())],
+                )
+            ]
+        )
+        context = MigrationContext.configure(dialect_name="sqlite")
+        eq_ignore_whitespace(
+            autogenerate.render_python_code(uo, migration_context=context),
+            "# ### commands auto generated by Alembic - please adjust! ###\n"
+            "    op.create_table('sometable',\n"
+            "    sa.Column('x', sa.DateTime(), "
+            "server_default=sa.text(!U'(CURRENT_TIMESTAMP)'), nullable=True)\n"
+            "    )\n"
+            "    # ### end Alembic commands ###",
+        )
+
     def test_repr_custom_type_w_sqla_prefix(self):
         self.autogen_context.opts["user_module_prefix"] = None
 
